@@ -1,12 +1,13 @@
 var NAVTREEINDEX4 =
 {
+"namespacelibcamera_1_1controls.html#aafa7f5668e13d77f07b32e1379986f37a159ab3879b3248929f0bce39143045da":[5,0,0,0,4,0],
 "namespacelibcamera_1_1controls.html#aafa7f5668e13d77f07b32e1379986f37a7ed2657b722d979b5e64a0140e8ddc22":[5,0,0,0,4,3],
 "namespacelibcamera_1_1controls.html#aafa7f5668e13d77f07b32e1379986f37af811cc2a6443ca654561a6d9969865fe":[5,0,0,0,4,2],
 "namespacelibcamera_1_1controls.html#ab0168c13ce47e2b586d315c56a3f38e7":[5,0,0,0,70],
 "namespacelibcamera_1_1controls.html#ab054b81391998f0361d1d12d18fbca1a":[5,0,0,0,30],
 "namespacelibcamera_1_1controls.html#ab2c40c5fe0916c0c1734fbb5b8e4faf2":[5,0,0,0,74],
 "namespacelibcamera_1_1controls.html#ab8b35e3d4c1f09a4a0c174e8cc8058f9":[5,0,0,0,49],
-"namespacelibcamera_1_1controls.html#ab91a634a47ee517c2f778dae71cdbafb":[5,0,0,0,100],
+"namespacelibcamera_1_1controls.html#ab91a634a47ee517c2f778dae71cdbafb":[5,0,0,0,101],
 "namespacelibcamera_1_1controls.html#abb16ff71758e1a0428f67d25c17bb384":[5,0,0,0,24],
 "namespacelibcamera_1_1controls.html#abcdb4732dbcabbc27812866e518f50f8":[5,0,0,0,59],
 "namespacelibcamera_1_1controls.html#abe26a34e0502b7e818dc2cf089e65375":[5,0,0,0,81],
@@ -28,7 +29,7 @@ var NAVTREEINDEX4 =
 "namespacelibcamera_1_1controls.html#acc370d05c5efc0b92f2fe285a1227426a81923f4508edfc9fa6d621d3f722931d":[5,0,0,0,3,0],
 "namespacelibcamera_1_1controls.html#acc370d05c5efc0b92f2fe285a1227426acda18269fbc96dde04bb9466b664670f":[5,0,0,0,3,2],
 "namespacelibcamera_1_1controls.html#acd98345a9c9b4cce25bb7fd086534490":[5,0,0,0,38],
-"namespacelibcamera_1_1controls.html#ace7f269a7d7e7dc55f05983d01ac8998":[5,0,0,0,103],
+"namespacelibcamera_1_1controls.html#ace7f269a7d7e7dc55f05983d01ac8998":[5,0,0,0,104],
 "namespacelibcamera_1_1controls.html#acf76d70e9ecf7778e78b5119e0001f58":[5,0,0,0,48],
 "namespacelibcamera_1_1controls.html#acfd700df550d86bff34a3e5d92cac40b":[5,0,0,0,97],
 "namespacelibcamera_1_1controls.html#ad012096d9a3e4e87aa7830ee0be1cab0":[5,0,0,0,95],
@@ -56,10 +57,10 @@ var NAVTREEINDEX4 =
 "namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977da992740e17e32bc905044d072d88197c5":[5,0,0,0,5,0],
 "namespacelibcamera_1_1controls.html#af0057ec539680c4c2b48ffb51842977daf1d9e674a9eddaa5ec6869c76a9fff52":[5,0,0,0,5,1],
 "namespacelibcamera_1_1controls.html#af406d4a9a43f1c5b4c1c4e38026468d1":[5,0,0,0,73],
-"namespacelibcamera_1_1controls.html#af5c53432fca9d7b03a43af1fc856c4bb":[5,0,0,0,110],
+"namespacelibcamera_1_1controls.html#af5c53432fca9d7b03a43af1fc856c4bb":[5,0,0,0,111],
 "namespacelibcamera_1_1controls.html#af8419d5eeb8689f5c27725b63d468ef2":[5,0,0,0,75],
-"namespacelibcamera_1_1controls.html#aff4ffa7b0862756c045212af24286020":[5,0,0,0,108],
-"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37":[5,0,0,0,105],
+"namespacelibcamera_1_1controls.html#aff4ffa7b0862756c045212af24286020":[5,0,0,0,109],
+"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37":[5,0,0,0,106],
 "namespacelibcamera_1_1controls_1_1debug.html":[5,0,0,0,2],
 "namespacelibcamera_1_1controls_1_1draft.html":[5,0,0,0,0],
 "namespacelibcamera_1_1controls_1_1draft.html#a001dd6c5c5f7b0620932ae874df94b22":[5,0,0,0,0,27],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "structlibcamera_1_1StreamConfiguration.html#a1e8e50caa5a44cfd2b432adab29e6439":[5,0,0,28,7],
 "structlibcamera_1_1StreamConfiguration.html#a1e8e50caa5a44cfd2b432adab29e6439":[6,0,0,26,7],
 "structlibcamera_1_1StreamConfiguration.html#a396e09188db732ef3f8a149808d876f7":[5,0,0,28,0],
-"structlibcamera_1_1StreamConfiguration.html#a396e09188db732ef3f8a149808d876f7":[6,0,0,26,0],
-"structlibcamera_1_1StreamConfiguration.html#a45980389297b2867581f7fbde6460c5c":[5,0,0,28,2]
+"structlibcamera_1_1StreamConfiguration.html#a396e09188db732ef3f8a149808d876f7":[6,0,0,26,0]
 };
